AddOn class abstract

Annotations
  • @BuiltValue.new()

Constructors

AddOn([void updates(AddOnBuilder b)])
factory

Properties

active bool
no setter
description String
no setter
displayName String
no setter
hashCode int
The hash code for this object.
no setterinherited
name String
no setter
priceNaira int
no setter
pricingModel String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(AddOnBuilder)) AddOn
Rebuilds the instance.
inherited
toBuilder() AddOnBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<AddOn>
no setter