AdminFull class abstract

AdminFull

Properties:

Implemented types
Annotations
  • @BuiltValue.new()

Constructors

AdminFull([void updates(AdminFullBuilder b)])
factory

Properties

createdAt DateTime
no setterinherited
disabled bool
no setter
disabledAt DateTime?
no setter
displayName String?
no setterinherited
email String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String
no setterinherited
lastLoginAt DateTime?
no setterinherited
password String?
Present ONLY on POST response when lockally generated the password. Shown once.
no setter
role AdminRoleEnum
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tenantId String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(AdminFullBuilder)) AdminFull
Rebuilds the instance.
inherited
toBuilder() AdminFullBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<AdminFull>
no setter