BillingStatusBuilder class

Constructors

BillingStatusBuilder()

Properties

catalog ↔ ListBuilder<PlanCatalogEntry>
getter/setter pair
createdAt DateTime?
getter/setter pair
currentPeriodEnd DateTime?
getter/setter pair
displayName String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
mode BillingStatusModeEnum?
getter/setter pair
monthlyIncludedSends int?
getter/setter pair
msgsThisPeriod int?
getter/setter pair
plan String?
getter/setter pair
priceNairaPerSeat int?
getter/setter pair
rateCapPerMin int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sendUnitsBalance int?
getter/setter pair
sendUnitsNextExpiry DateTime?
getter/setter pair
status BillingStatusStatusEnum?
getter/setter pair
subscribedAt DateTime?
getter/setter pair
unitBundles ↔ ListBuilder<UnitBundle>
getter/setter pair

Methods

build() BillingStatus
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(BillingStatus other) → void
Replaces the value in the builder with a new one.
override
toString() String
A string representation of this object.
inherited
update(void updates(BillingStatusBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited