listContacts method

Future<Response<ListContacts200Response>> listContacts({
  1. String? q,
  2. String? type,
  3. String? department,
  4. String? status,
  5. String? source_,
  6. CancelToken? cancelToken,
  7. Map<String, dynamic>? headers,
  8. Map<String, dynamic>? extra,
  9. ValidateStatus? validateStatus,
  10. ProgressCallback? onSendProgress,
  11. ProgressCallback? onReceiveProgress,
})

List contacts

Parameters:

  • q - Free-text search across name, email, company
  • type - Filter by contact_type
  • department - Filter by department
  • status - Filter by status
  • source_ - Filter by source
  • cancelToken - A CancelToken that can be used to cancel the operation
  • headers - Can be used to add additional headers to the request
  • extras - Can be used to add flags to the request
  • validateStatus - A ValidateStatus callback that can be used to determine request success based on the HTTP status of the response
  • onSendProgress - A ProgressCallback that can be used to get the send progress
  • onReceiveProgress - A ProgressCallback that can be used to get the receive progress

Returns a Future containing a Response with a ListContacts200Response as data Throws DioException if API call or serialization fails

Implementation

Future<Response<ListContacts200Response>> listContacts({
  String? q,
  String? type,
  String? department,
  String? status,
  String? source_,
  CancelToken? cancelToken,
  Map<String, dynamic>? headers,
  Map<String, dynamic>? extra,
  ValidateStatus? validateStatus,
  ProgressCallback? onSendProgress,
  ProgressCallback? onReceiveProgress,
}) async {
  final _path = r'/v1/contacts';
  final _options = Options(
    method: r'GET',
    headers: <String, dynamic>{
      ...?headers,
    },
    extra: <String, dynamic>{
      'secure': <Map<String, String>>[
        {
          'type': 'http',
          'scheme': 'bearer',
          'name': 'bearerAuth',
        },
      ],
      ...?extra,
    },
    validateStatus: validateStatus,
  );

  final _queryParameters = <String, dynamic>{
    if (q != null) r'q': encodeQueryParameter(_serializers, q, const FullType(String)),
    if (type != null) r'type': encodeQueryParameter(_serializers, type, const FullType(String)),
    if (department != null) r'department': encodeQueryParameter(_serializers, department, const FullType(String)),
    if (status != null) r'status': encodeQueryParameter(_serializers, status, const FullType(String)),
    if (source_ != null) r'source': encodeQueryParameter(_serializers, source_, const FullType(String)),
  };

  final _response = await _dio.request<Object>(
    _path,
    options: _options,
    queryParameters: _queryParameters,
    cancelToken: cancelToken,
    onSendProgress: onSendProgress,
    onReceiveProgress: onReceiveProgress,
  );

  ListContacts200Response? _responseData;

  try {
    final rawResponse = _response.data;
    _responseData = rawResponse == null ? null : _serializers.deserialize(
      rawResponse,
      specifiedType: const FullType(ListContacts200Response),
    ) as ListContacts200Response;

  } catch (error, stackTrace) {
    throw DioException(
      requestOptions: _response.requestOptions,
      response: _response,
      type: DioExceptionType.unknown,
      error: error,
      stackTrace: stackTrace,
    );
  }

  return Response<ListContacts200Response>(
    data: _responseData,
    headers: _response.headers,
    isRedirect: _response.isRedirect,
    requestOptions: _response.requestOptions,
    redirects: _response.redirects,
    statusCode: _response.statusCode,
    statusMessage: _response.statusMessage,
    extra: _response.extra,
  );
}