DirectoryPermissions class abstract
DirectoryPermissions
Properties:
- Annotations
-
- @BuiltValue.new()
Constructors
- DirectoryPermissions([void updates(DirectoryPermissionsBuilder b)])
-
factory
Properties
- contactEditAccess → DirectoryPermissionsContactEditAccessEnum
-
no setter
- contactViewAccess → DirectoryPermissionsContactViewAccessEnum
-
no setter
- createdAt → DateTime?
-
no setter
- externalSharing → DirectoryPermissionsExternalSharingEnum
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- listManageAccess → DirectoryPermissionsListManageAccessEnum
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tenantId → String
-
no setter
- updatedAt → DateTime?
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(DirectoryPermissionsBuilder)) → DirectoryPermissions -
Rebuilds the instance.
inherited
-
toBuilder(
) → DirectoryPermissionsBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
DirectoryPermissions> -
no setter