GetDomainsStatus200Response class abstract

GetDomainsStatus200Response

Properties:

Annotations
  • @BuiltValue.new()

Constructors

GetDomainsStatus200Response([void updates(GetDomainsStatus200ResponseBuilder b)])
factory

Properties

domains → BuiltList<GetDomainsStatus200ResponseDomainsInner>?
no setter
generatedAt DateTime?
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(GetDomainsStatus200ResponseBuilder)) GetDomainsStatus200Response
Rebuilds the instance.
inherited
toBuilder() GetDomainsStatus200ResponseBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<GetDomainsStatus200Response>
no setter