GetEncryptionKey200Response class abstract
- Annotations
-
- @BuiltValue.new()
Constructors
- GetEncryptionKey200Response([void updates(GetEncryptionKey200ResponseBuilder b)])
-
factory
Properties
- email → String?
-
no setter
- encryptedPrivateKey → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
no setter
- kdfParams → JsonObject?
-
no setter
- publicKey → String?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version → int?
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(GetEncryptionKey200ResponseBuilder)) → GetEncryptionKey200Response -
Rebuilds the instance.
inherited
-
toBuilder(
) → GetEncryptionKey200ResponseBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
GetEncryptionKey200Response> -
no setter