GetIntegrationsSummary200ResponseApiKeysInner class abstract
- Annotations
-
- @BuiltValue.new()
Constructors
- GetIntegrationsSummary200ResponseApiKeysInner([void updates(GetIntegrationsSummary200ResponseApiKeysInnerBuilder b)])
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String?
-
no setter
- lastUsedAt → DateTime?
-
no setter
- prefix → String?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(GetIntegrationsSummary200ResponseApiKeysInnerBuilder)) → GetIntegrationsSummary200ResponseApiKeysInner -
Rebuilds the instance.
inherited
-
toBuilder(
) → GetIntegrationsSummary200ResponseApiKeysInnerBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
GetIntegrationsSummary200ResponseApiKeysInner> -
no setter