ListMigrationEvents200Response class abstract
- Annotations
-
- @BuiltValue.new()
Constructors
- ListMigrationEvents200Response([void updates(ListMigrationEvents200ResponseBuilder b)])
-
factory
Properties
-
data
→ BuiltList<
MigrationEvent> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(ListMigrationEvents200ResponseBuilder)) → ListMigrationEvents200Response -
Rebuilds the instance.
inherited
-
toBuilder(
) → ListMigrationEvents200ResponseBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
ListMigrationEvents200Response> -
no setter