MailboxBuilder class
Constructors
Properties
- createdAt ↔ DateTime?
-
getter/setter pair
- disabled ↔ bool?
-
getter/setter pair
- disabledAt ↔ DateTime?
-
getter/setter pair
- domainId ↔ String?
-
getter/setter pair
- email ↔ String?
-
getter/setter pair
- hardDeleteAfter ↔ DateTime?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
getter/setter pair
- password ↔ String?
-
getter/setter pair
- quotaBytes ↔ int?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- softDeletedAt ↔ DateTime?
-
getter/setter pair
- tenantId ↔ String?
-
getter/setter pair
Methods
-
build(
) → Mailbox -
Builds.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
replace(
Mailbox other) → void -
Replaces the value in the builder with a new one.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
void updates(MailboxBuilder)?) → void -
Applies updates.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited