Migration class abstract

Annotations
  • @BuiltValue.new()

Constructors

Migration([void updates(MigrationBuilder b)])
factory

Properties

completedAt DateTime?
no setter
createdAt DateTime
no setter
credentialId String
no setter
errorMessage String?
no setter
hashCode int
The hash code for this object.
no setterinherited
id String
no setter
mailboxCount int
no setter
name String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settings MigrationSettings?
no setter
sourceProvider String
no setter
sourceSummary String?
no setter
startedAt DateTime?
no setter
status MigrationStatusEnum
no setter
tenantId String
no setter
updatedAt DateTime
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(MigrationBuilder)) Migration
Rebuilds the instance.
inherited
toBuilder() MigrationBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<Migration>
no setter