ReplaceDistributionListMembers200ResponseBuilder class

Properties

hashCode int
The hash code for this object.
no setterinherited
id String?
getter/setter pair
listAddress String?
getter/setter pair
memberCount int?
getter/setter pair
members ↔ ListBuilder<String>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tenantId String?
getter/setter pair

Methods

build() ReplaceDistributionListMembers200Response
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(ReplaceDistributionListMembers200Response other) → void
Replaces the value in the builder with a new one.
override
toString() String
A string representation of this object.
inherited
update(void updates(ReplaceDistributionListMembers200ResponseBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited