TenantBuilder class
Constructors
Properties
- adminEmail ↔ String?
-
getter/setter pair
- closedAt ↔ DateTime?
-
getter/setter pair
- createdAt ↔ DateTime?
-
getter/setter pair
- dailyMsgQuota ↔ int?
-
getter/setter pair
- displayName ↔ String?
-
getter/setter pair
- hardDeleteAfter ↔ DateTime?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
getter/setter pair
- plan ↔ String?
-
getter/setter pair
- rateCapPerMin ↔ int?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- slug ↔ String?
-
getter/setter pair
- status ↔ TenantStatusEnum?
-
getter/setter pair
- suspendedAt ↔ DateTime?
-
getter/setter pair
Methods
-
build(
) → Tenant -
Builds.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
replace(
Tenant other) → void -
Replaces the value in the builder with a new one.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
void updates(TenantBuilder)?) → void -
Applies updates.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited