OAuthConfig class

OAuth 2.1 authorization-code + PKCE configuration.

Constructors

OAuthConfig({required String clientId, required String redirectUri, List<String> scopes = const ['inboxes:read', 'inboxes:write'], String authorizationEndpoint = 'https://api.lockally.com/oauth/authorize', String tokenEndpoint = 'https://api.lockally.com/oauth/token'})

Properties

authorizationEndpoint String
final
clientId String
final
hashCode int
The hash code for this object.
no setterinherited
redirectUri String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scopes List<String>
final
tokenEndpoint String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited