Page<T> class

A page of results from a cursor-paginated endpoint.

Constructors

Page(List<T> items, String? nextCursor)

Properties

hashCode int
The hash code for this object.
no setterinherited
items List<T>
final
nextCursor String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited