StaticTokenProvider class

A fixed key. Do not embed a lk_live_* key in a distributed app — it is extractable from the bundle. Fine for server-side/internal use and lk_test_*.

Implemented types

Constructors

StaticTokenProvider(String _value)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
token() Future<String>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited