TokenProvider class abstract

Supplies the bearer credential for each request. Async so it can refresh an expiring token or fetch a short-lived one from your backend.

Implementers

Constructors

TokenProvider()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
token() Future<String>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited