TokenStore class abstract

Where OAuth refresh tokens are persisted between launches.

On Flutter, implement with flutter_secure_storage (Keychain / Keystore):

class SecureTokenStore implements TokenStore {
  final _s = const FlutterSecureStorage();
  @override Future<String?> read(String k) => _s.read(key: k);
  @override Future<void> write(String k, String v) => _s.write(key: k, value: v);
  @override Future<void> delete(String k) => _s.delete(key: k);
}
Implementers

Constructors

TokenStore()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(String key) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(String key) Future<String?>
toString() String
A string representation of this object.
inherited
write(String key, String value) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited