GALSettingsBuilder class
Constructors
Properties
- createdAt ↔ DateTime?
-
getter/setter pair
- departmentGrouping ↔ bool?
-
getter/setter pair
- galEnabled ↔ bool?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hideFromDirectory ↔ bool?
-
getter/setter pair
- includeExternalContacts ↔ bool?
-
getter/setter pair
- lastIndexRebuiltAt ↔ DateTime?
-
getter/setter pair
- lastSyncedAt ↔ DateTime?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchVisibility ↔ GALSettingsSearchVisibilityEnum?
-
getter/setter pair
- tenantId ↔ String?
-
getter/setter pair
- updatedAt ↔ DateTime?
-
getter/setter pair
Methods
-
build(
) → GALSettings -
Builds.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
replace(
GALSettings other) → void -
Replaces the value in the builder with a new one.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
void updates(GALSettingsBuilder)?) → void -
Applies updates.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited