UnitBundle class abstract
- Annotations
-
- @BuiltValue.new()
Constructors
- UnitBundle([void updates(UnitBundleBuilder b)])
-
factory
Properties
- displayName → String
-
no setter
- displayPrice → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String
-
no setter
- priceNaira → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- units → int
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(UnitBundleBuilder)) → UnitBundle -
Rebuilds the instance.
inherited
-
toBuilder(
) → UnitBundleBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
UnitBundle> -
no setter