LockallyInterceptor class
A single dio Interceptor that:
- injects
Authorization: Bearerfrom a TokenProvider (refreshed per try), - adds a stable
Idempotency-Keyon mutating requests, and - retries network errors /
429/5xxwith backoff + jitter, honoringRetry-After.
Constructors
- LockallyInterceptor(Dio _dio, TokenProvider _provider, {RetryPolicy policy = const RetryPolicy()})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onError(
DioException err, ErrorInterceptorHandler handler) → Future< void> - Called when an exception was occurred during the request.
-
onRequest(
RequestOptions options, RequestInterceptorHandler handler) → Future< void> - Called when the request is about to be sent.
-
onResponse(
Response response, ResponseInterceptorHandler handler) → void -
Called when the response is about to be resolved.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited